==> linalg-1.7.4.tar.gz: linalg-1.7.4/docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "blas", "namespaceblas.html", [
      [ "dgbmv", "interfaceblas_1_1dgbmv.html", null ],
      [ "dgemm", "interfaceblas_1_1dgemm.html", null ],
      [ "dgemv", "interfaceblas_1_1dgemv.html", null ],
      [ "dscal", "interfaceblas_1_1dscal.html", null ],
      [ "dtrsm", "interfaceblas_1_1dtrsm.html", null ],
      [ "dtrsv", "interfaceblas_1_1dtrsv.html", null ],
      [ "zdscal", "interfaceblas_1_1zdscal.html", null ],
      [ "zgbmv", "interfaceblas_1_1zgbmv.html", null ],
      [ "zgemm", "interfaceblas_1_1zgemm.html", null ],
      [ "zgemv", "interfaceblas_1_1zgemv.html", null ],
      [ "zscal", "interfaceblas_1_1zscal.html", null ],
      [ "ztrsm", "interfaceblas_1_1ztrsm.html", null ],
      [ "ztrsv", "interfaceblas_1_1ztrsv.html", null ]
    ] ],
    [ "lapack", null, [
      [ "dgeev", "interfacelapack_1_1dgeev.html", null ],
      [ "dgelqf", "interfacelapack_1_1dgelqf.html", null ],
      [ "dgels", "interfacelapack_1_1dgels.html", null ],
      [ "dgelss", "interfacelapack_1_1dgelss.html", null ],
      [ "dgelsy", "interfacelapack_1_1dgelsy.html", null ],
      [ "dgeqp3", "interfacelapack_1_1dgeqp3.html", null ],
      [ "dgeqrf", "interfacelapack_1_1dgeqrf.html", null ],
      [ "dgesvd", "interfacelapack_1_1dgesvd.html", null ],
      [ "dgetrf", "interfacelapack_1_1dgetrf.html", null ],
      [ "dgetri", "interfacelapack_1_1dgetri.html", null ],
      [ "dgetrs", "interfacelapack_1_1dgetrs.html", null ],
      [ "dggev", "interfacelapack_1_1dggev.html", null ],
      [ "dlaic1", "interfacelapack_1_1dlaic1.html", null ],
      [ "dlamch", "interfacelapack_1_1dlamch.html", null ],
      [ "dlaset", "interfacelapack_1_1dlaset.html", null ],
      [ "dlasrt", "interfacelapack_1_1dlasrt.html", null ],
      [ "dorglq", "interfacelapack_1_1dorglq.html", null ],
      [ "dorgqr", "interfacelapack_1_1dorgqr.html", null ],
      [ "dormlq", "interfacelapack_1_1dormlq.html", null ],
      [ "dormqr", "interfacelapack_1_1dormqr.html", null ],
      [ "dormrz", "interfacelapack_1_1dormrz.html", null ],
      [ "dpotrf", "interfacelapack_1_1dpotrf.html", null ],
      [ "dpotrs", "interfacelapack_1_1dpotrs.html", null ],
      [ "dsyev", "interfacelapack_1_1dsyev.html", null ],
      [ "dtzrzf", "interfacelapack_1_1dtzrzf.html", null ],
      [ "zgeev", "interfacelapack_1_1zgeev.html", null ],
      [ "zgelqf", "interfacelapack_1_1zgelqf.html", null ],
      [ "zgels", "interfacelapack_1_1zgels.html", null ],
      [ "zgelss", "interfacelapack_1_1zgelss.html", null ],
      [ "zgelsy", "interfacelapack_1_1zgelsy.html", null ],
      [ "zgeqp3", "interfacelapack_1_1zgeqp3.html", null ],
      [ "zgeqrf", "interfacelapack_1_1zgeqrf.html", null ],
      [ "zgesvd", "interfacelapack_1_1zgesvd.html", null ],
      [ "zgetrf", "interfacelapack_1_1zgetrf.html", null ],
      [ "zgetri", "interfacelapack_1_1zgetri.html", null ],
      [ "zgetrs", "interfacelapack_1_1zgetrs.html", null ],
      [ "zlaic1", "interfacelapack_1_1zlaic1.html", null ],
      [ "zpotrf", "interfacelapack_1_1zpotrf.html", null ],
      [ "zpotrs", "interfacelapack_1_1zpotrs.html", null ],
      [ "ztzrzf", "interfacelapack_1_1ztzrzf.html", null ],
      [ "zunglq", "interfacelapack_1_1zunglq.html", null ],
      [ "zungqr", "interfacelapack_1_1zungqr.html", null ],
      [ "zunmlq", "interfacelapack_1_1zunmlq.html", null ],
      [ "zunmqr", "interfacelapack_1_1zunmqr.html", null ],
      [ "zunmrz", "interfacelapack_1_1zunmrz.html", null ]
    ] ],
    [ "linalg", "namespacelinalg.html", [
      [ "band_diag_mtx_mult", "interfacelinalg_1_1band__diag__mtx__mult.html", null ],
      [ "band_mtx_mult", "interfacelinalg_1_1band__mtx__mult.html", null ],
      [ "band_mtx_to_full_mtx", "interfacelinalg_1_1band__mtx__to__full__mtx.html", null ],
      [ "cholesky_factor", "interfacelinalg_1_1cholesky__factor.html", null ],
      [ "cholesky_rank1_downdate", "interfacelinalg_1_1cholesky__rank1__downdate.html", null ],
      [ "cholesky_rank1_update", "interfacelinalg_1_1cholesky__rank1__update.html", null ],
      [ "det", "interfacelinalg_1_1det.html", null ],
      [ "diag_mtx_mult", "interfacelinalg_1_1diag__mtx__mult.html", null ],
      [ "eigen", "interfacelinalg_1_1eigen.html", null ],
      [ "form_lq", "interfacelinalg_1_1form__lq.html", null ],
      [ "form_lu", "interfacelinalg_1_1form__lu.html", null ],
      [ "form_qr", "interfacelinalg_1_1form__qr.html", null ],
      [ "lq_factor", "interfacelinalg_1_1lq__factor.html", null ],
      [ "lu_factor", "interfacelinalg_1_1lu__factor.html", null ],
      [ "mtx_inverse", "interfacelinalg_1_1mtx__inverse.html", null ],
      [ "mtx_mult", "interfacelinalg_1_1mtx__mult.html", null ],
      [ "mtx_pinverse", "interfacelinalg_1_1mtx__pinverse.html", null ],
      [ "mtx_rank", "interfacelinalg_1_1mtx__rank.html", null ],
      [ "mult_lq", "interfacelinalg_1_1mult__lq.html", null ],
      [ "mult_qr", "interfacelinalg_1_1mult__qr.html", null ],
      [ "mult_rz", "interfacelinalg_1_1mult__rz.html", null ],
      [ "qr_factor", "interfacelinalg_1_1qr__factor.html", null ],
      [ "qr_rank1_update", "interfacelinalg_1_1qr__rank1__update.html", null ],
      [ "rank1_update", "interfacelinalg_1_1rank1__update.html", null ],
      [ "recip_mult_array", "interfacelinalg_1_1recip__mult__array.html", null ],
      [ "rz_factor", "interfacelinalg_1_1rz__factor.html", null ],
      [ "solve_cholesky", "interfacelinalg_1_1solve__cholesky.html", null ],
      [ "solve_least_squares", "interfacelinalg_1_1solve__least__squares.html", null ],
      [ "solve_least_squares_full", "interfacelinalg_1_1solve__least__squares__full.html", null ],
      [ "solve_least_squares_svd", "interfacelinalg_1_1solve__least__squares__svd.html", null ],
      [ "solve_lq", "interfacelinalg_1_1solve__lq.html", null ],
      [ "solve_lu", "interfacelinalg_1_1solve__lu.html", null ],
      [ "solve_qr", "interfacelinalg_1_1solve__qr.html", null ],
      [ "solve_triangular_system", "interfacelinalg_1_1solve__triangular__system.html", null ],
      [ "sort", "interfacelinalg_1_1sort.html", null ],
      [ "svd", "interfacelinalg_1_1svd.html", null ],
      [ "swap", "interfacelinalg_1_1swap.html", null ],
      [ "trace", "interfacelinalg_1_1trace.html", null ],
      [ "tri_mtx_mult", "interfacelinalg_1_1tri__mtx__mult.html", null ]
    ] ],
    [ "qrupdate", "namespaceqrupdate.html", [
      [ "dch1dn", "interfaceqrupdate_1_1dch1dn.html", null ],
      [ "dch1up", "interfaceqrupdate_1_1dch1up.html", null ],
      [ "dqr1up", "interfaceqrupdate_1_1dqr1up.html", null ],
      [ "zch1dn", "interfaceqrupdate_1_1zch1dn.html", null ],
      [ "zch1up", "interfaceqrupdate_1_1zch1up.html", null ],
      [ "zqr1up", "interfaceqrupdate_1_1zqr1up.html", null ]
    ] ]
];

==> linalg-1.8.2.tar.gz: linalg-1.8.2/docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "blas", "namespaceblas.html", [
      [ "ddot", "interfaceblas_1_1ddot.html", null ],
      [ "dgbmv", "interfaceblas_1_1dgbmv.html", null ],
      [ "dgemm", "interfaceblas_1_1dgemm.html", null ],
      [ "dgemv", "interfaceblas_1_1dgemv.html", null ],
      [ "dscal", "interfaceblas_1_1dscal.html", null ],
      [ "dtrsm", "interfaceblas_1_1dtrsm.html", null ],
      [ "dtrsv", "interfaceblas_1_1dtrsv.html", null ],
      [ "zdscal", "interfaceblas_1_1zdscal.html", null ],
      [ "zgbmv", "interfaceblas_1_1zgbmv.html", null ],
      [ "zgemm", "interfaceblas_1_1zgemm.html", null ],
      [ "zgemv", "interfaceblas_1_1zgemv.html", null ],
      [ "zscal", "interfaceblas_1_1zscal.html", null ],
      [ "ztrsm", "interfaceblas_1_1ztrsm.html", null ],
      [ "ztrsv", "interfaceblas_1_1ztrsv.html", null ]
    ] ],
    [ "lapack", null, [
      [ "dgeev", "interfacelapack_1_1dgeev.html", null ],
      [ "dgelqf", "interfacelapack_1_1dgelqf.html", null ],
      [ "dgels", "interfacelapack_1_1dgels.html", null ],
      [ "dgelss", "interfacelapack_1_1dgelss.html", null ],
      [ "dgelsy", "interfacelapack_1_1dgelsy.html", null ],
      [ "dgeqp3", "interfacelapack_1_1dgeqp3.html", null ],
      [ "dgeqrf", "interfacelapack_1_1dgeqrf.html", null ],
      [ "dgesvd", "interfacelapack_1_1dgesvd.html", null ],
      [ "dgetrf", "interfacelapack_1_1dgetrf.html", null ],
      [ "dgetri", "interfacelapack_1_1dgetri.html", null ],
      [ "dgetrs", "interfacelapack_1_1dgetrs.html", null ],
      [ "dggev", "interfacelapack_1_1dggev.html", null ],
      [ "dlaic1", "interfacelapack_1_1dlaic1.html", null ],
      [ "dlamch", "interfacelapack_1_1dlamch.html", null ],
      [ "dlaset", "interfacelapack_1_1dlaset.html", null ],
      [ "dlasrt", "interfacelapack_1_1dlasrt.html", null ],
      [ "dorglq", "interfacelapack_1_1dorglq.html", null ],
      [ "dorgqr", "interfacelapack_1_1dorgqr.html", null ],
      [ "dormlq", "interfacelapack_1_1dormlq.html", null ],
      [ "dormqr", "interfacelapack_1_1dormqr.html", null ],
      [ "dormrz", "interfacelapack_1_1dormrz.html", null ],
      [ "dpotrf", "interfacelapack_1_1dpotrf.html", null ],
      [ "dpotrs", "interfacelapack_1_1dpotrs.html", null ],
      [ "dsyev", "interfacelapack_1_1dsyev.html", null ],
      [ "dtzrzf", "interfacelapack_1_1dtzrzf.html", null ],
      [ "zgeev", "interfacelapack_1_1zgeev.html", null ],
      [ "zgelqf", "interfacelapack_1_1zgelqf.html", null ],
      [ "zgels", "interfacelapack_1_1zgels.html", null ],
      [ "zgelss", "interfacelapack_1_1zgelss.html", null ],
      [ "zgelsy", "interfacelapack_1_1zgelsy.html", null ],
      [ "zgeqp3", "interfacelapack_1_1zgeqp3.html", null ],
      [ "zgeqrf", "interfacelapack_1_1zgeqrf.html", null ],
      [ "zgesvd", "interfacelapack_1_1zgesvd.html", null ],
      [ "zgetrf", "interfacelapack_1_1zgetrf.html", null ],
      [ "zgetri", "interfacelapack_1_1zgetri.html", null ],
      [ "zgetrs", "interfacelapack_1_1zgetrs.html", null ],
      [ "zlaic1", "interfacelapack_1_1zlaic1.html", null ],
      [ "zpotrf", "interfacelapack_1_1zpotrf.html", null ],
      [ "zpotrs", "interfacelapack_1_1zpotrs.html", null ],
      [ "ztzrzf", "interfacelapack_1_1ztzrzf.html", null ],
      [ "zunglq", "interfacelapack_1_1zunglq.html", null ],
      [ "zungqr", "interfacelapack_1_1zungqr.html", null ],
      [ "zunmlq", "interfacelapack_1_1zunmlq.html", null ],
      [ "zunmqr", "interfacelapack_1_1zunmqr.html", null ],
      [ "zunmrz", "interfacelapack_1_1zunmrz.html", null ]
    ] ],
    [ "linalg", "namespacelinalg.html", [
      [ "band_diag_mtx_mult", "interfacelinalg_1_1band__diag__mtx__mult.html", null ],
      [ "band_mtx_mult", "interfacelinalg_1_1band__mtx__mult.html", null ],
      [ "band_mtx_to_full_mtx", "interfacelinalg_1_1band__mtx__to__full__mtx.html", null ],
      [ "banded_to_dense", "interfacelinalg_1_1banded__to__dense.html", null ],
      [ "cholesky_factor", "interfacelinalg_1_1cholesky__factor.html", null ],
      [ "cholesky_rank1_downdate", "interfacelinalg_1_1cholesky__rank1__downdate.html", null ],
      [ "cholesky_rank1_update", "interfacelinalg_1_1cholesky__rank1__update.html", null ],
      [ "csr_matrix", "structlinalg_1_1csr__matrix.html", "structlinalg_1_1csr__matrix" ],
      [ "dense_to_banded", "interfacelinalg_1_1dense__to__banded.html", null ],
      [ "det", "interfacelinalg_1_1det.html", null ],
      [ "diag_mtx_mult", "interfacelinalg_1_1diag__mtx__mult.html", null ],
      [ "eigen", "interfacelinalg_1_1eigen.html", null ],
      [ "extract_diagonal", "interfacelinalg_1_1extract__diagonal.html", null ],
      [ "form_lq", "interfacelinalg_1_1form__lq.html", null ],
      [ "form_lu", "interfacelinalg_1_1form__lu.html", null ],
      [ "form_qr", "interfacelinalg_1_1form__qr.html", null ],
      [ "lq_factor", "interfacelinalg_1_1lq__factor.html", null ],
      [ "lu_factor", "interfacelinalg_1_1lu__factor.html", null ],
      [ "matmul", "interfacelinalg_1_1matmul.html", null ],
      [ "msr_matrix", "structlinalg_1_1msr__matrix.html", "structlinalg_1_1msr__matrix" ],
      [ "mtx_inverse", "interfacelinalg_1_1mtx__inverse.html", null ],
      [ "mtx_mult", "interfacelinalg_1_1mtx__mult.html", null ],
      [ "mtx_pinverse", "interfacelinalg_1_1mtx__pinverse.html", null ],
      [ "mtx_rank", "interfacelinalg_1_1mtx__rank.html", null ],
      [ "mult_lq", "interfacelinalg_1_1mult__lq.html", null ],
      [ "mult_qr", "interfacelinalg_1_1mult__qr.html", null ],
      [ "mult_rz", "interfacelinalg_1_1mult__rz.html", null ],
      [ "nonzero_count", "interfacelinalg_1_1nonzero__count.html", null ],
      [ "operator(*)", "interfacelinalg_1_1operator_07_5_08.html", null ],
      [ "operator(+)", "interfacelinalg_1_1operator_07_09_08.html", null ],
      [ "operator(-)", "interfacelinalg_1_1operator_07-_08.html", null ],
      [ "operator(/)", "interfacelinalg_1_1operator_07_2_08.html", null ],
      [ "pgmres_solver", "interfacelinalg_1_1pgmres__solver.html", null ],
      [ "qr_factor", "interfacelinalg_1_1qr__factor.html", null ],
      [ "qr_rank1_update", "interfacelinalg_1_1qr__rank1__update.html", null ],
      [ "rank1_update", "interfacelinalg_1_1rank1__update.html", null ],
      [ "recip_mult_array", "interfacelinalg_1_1recip__mult__array.html", null ],
      [ "rz_factor", "interfacelinalg_1_1rz__factor.html", null ],
      [ "size", "interfacelinalg_1_1size.html", null ],
      [ "solve_cholesky", "interfacelinalg_1_1solve__cholesky.html", null ],
      [ "solve_least_squares", "interfacelinalg_1_1solve__least__squares.html", null ],
      [ "solve_least_squares_full", "interfacelinalg_1_1solve__least__squares__full.html", null ],
      [ "solve_least_squares_svd", "interfacelinalg_1_1solve__least__squares__svd.html", null ],
      [ "solve_lq", "interfacelinalg_1_1solve__lq.html", null ],
      [ "solve_lu", "interfacelinalg_1_1solve__lu.html", null ],
      [ "solve_qr", "interfacelinalg_1_1solve__qr.html", null ],
      [ "solve_triangular_system", "interfacelinalg_1_1solve__triangular__system.html", null ],
      [ "sort", "interfacelinalg_1_1sort.html", null ],
      [ "sparse_direct_solve", "interfacelinalg_1_1sparse__direct__solve.html", null ],
      [ "svd", "interfacelinalg_1_1svd.html", null ],
      [ "swap", "interfacelinalg_1_1swap.html", null ],
      [ "trace", "interfacelinalg_1_1trace.html", null ],
      [ "transpose", "interfacelinalg_1_1transpose.html", null ],
      [ "tri_mtx_mult", "interfacelinalg_1_1tri__mtx__mult.html", null ]
    ] ],
    [ "qrupdate", "namespaceqrupdate.html", [
      [ "dch1dn", "interfaceqrupdate_1_1dch1dn.html", null ],
      [ "dch1up", "interfaceqrupdate_1_1dch1up.html", null ],
      [ "dqr1up", "interfaceqrupdate_1_1dqr1up.html", null ],
      [ "zch1dn", "interfaceqrupdate_1_1zch1dn.html", null ],
      [ "zch1up", "interfaceqrupdate_1_1zch1up.html", null ],
      [ "zqr1up", "interfaceqrupdate_1_1zqr1up.html", null ]
    ] ],
    [ "sparskit", "namespacesparskit.html", [
      [ "amub", "interfacesparskit_1_1amub.html", null ],
      [ "aplb", "interfacesparskit_1_1aplb.html", null ],
      [ "aplsb", "interfacesparskit_1_1aplsb.html", null ],
      [ "bndcsr", "interfacesparskit_1_1bndcsr.html", null ],
      [ "clncsr", "interfacesparskit_1_1clncsr.html", null ],
      [ "coocsr", "interfacesparskit_1_1coocsr.html", null ],
      [ "csort", "interfacesparskit_1_1csort.html", null ],
      [ "csrcsc2", "interfacesparskit_1_1csrcsc2.html", null ],
      [ "csrmsr", "interfacesparskit_1_1csrmsr.html", null ],
      [ "getdia", "interfacesparskit_1_1getdia.html", null ],
      [ "getelm", "interfacesparskit_1_1getelm.html", null ],
      [ "ilud", "interfacesparskit_1_1ilud.html", null ],
      [ "iludp", "interfacesparskit_1_1iludp.html", null ],
      [ "ilut", "interfacesparskit_1_1ilut.html", null ],
      [ "ilutp", "interfacesparskit_1_1ilutp.html", null ],
      [ "lusol", "interfacesparskit_1_1lusol.html", null ],
      [ "msrcsr", "interfacesparskit_1_1msrcsr.html", null ],
      [ "pgmres", "interfacesparskit_1_1pgmres.html", null ]
    ] ]
];
